@@ -57,17 +57,3 @@ def config(monkeypatch, sample_token, sample_url):
     config.kbapi_url = sample_url
     config.auth_token = sample_token
     return config
-
-
-@pytest.fixture
-def config_valid_token(config, mocker):
-    mocker.patch("tuxsuite.config.Config.check_auth_token")
-    return config
-
-
-@pytest.fixture
-def config_invalid_token(config, mocker):
-    mocker.patch(
-        "tuxsuite.config.Config.check_auth_token", side_effect=RuntimeError("BOOM")
-    )
-    return config
