@@ -2,6 +2,7 @@
 
 import json
 import pytest
+import queue
 import tuxsuite.build
 import requests
 import tuxsuite.exceptions
@@ -127,6 +128,8 @@ def sleep(mocker, start_time):
 @pytest.fixture
 def build_attrs():
     return {
+        "group": "tuxsuite",
+        "project": "unittests",
         "git_repo": "http://github.com/torvalds/linux",
         "git_ref": "master",
         "target_arch": "arm",
@@ -574,6 +577,8 @@ def builds():
 def build_set(build_attrs, builds):
     return tuxsuite.build.BuildSet(
         builds,
+        group=build_attrs["group"],
+        project=build_attrs["project"],
         git_repo=build_attrs["git_repo"],
         git_ref=build_attrs["git_ref"],
         kbapi_url=build_attrs["kbapi_url"],
@@ -637,6 +642,18 @@ class TestBuildSetWatch(TestWatch):
         states = self.watch(build_set)
         assert len(states) == 2 * len(build_set.builds)
 
+    def test_watch_when_threads_crash(self, build_set, mocker, capsys):
+        build_watch = mocker.patch("tuxsuite.build.Build.watch")
+        build_watch.side_effect = RuntimeError("BOOM")
+        mocker.patch("queue.Queue.get", side_effect=queue.Empty)
+
+        self.watch(build_set)
+
+        # if the test reaches this point, it means BuildSet.watch didn't get
+        # stuck waiting forever.
+        _, err = capsys.readouterr()
+        assert "ERROR for build" in err
+
 
 class TestBuildSetWait:
     def test_wait(self, build_set, mocker):
