@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
 import pytest
-import requests
 import tuxsuite.config
 import tuxsuite.exceptions
 
@@ -108,18 +107,6 @@ api_url={}
     assert c.get_tuxsuite_env() == c.tuxsuite_env
 
 
-def test_check_auth_token_valid(config, sample_url, get, response, mocker):
-    response.status_code = 200
-    config.check_auth_token()
-    get.assert_called_with(f"{sample_url}/verify", headers=mocker.ANY)
-
-
-def test_check_auth_token_invalid(config, sample_url, get, response):
-    response.status_code = 400
-    with pytest.raises(requests.HTTPError):
-        config.check_auth_token()
-
-
 class TestBackwardsCompatibilityWithTuxBuild:
     @pytest.fixture
     def config_dir(self, home):
