@@ -2,7 +2,6 @@
 
 from . import build
 from . import config
-from . import exceptions
 import logging
 
 
@@ -16,11 +15,6 @@ def load_config():
     global __config__
     if not __config__:
         __config__ = config.Config()
-        try:
-            __config__.check_auth_token()
-        except Exception as e:
-            __config__ = None
-            raise exceptions.InvalidToken("😔 Invalid Token: " + str(e))
     return __config__
 
 
@@ -31,6 +25,10 @@ class Configurable:
             kwargs["token"] = cfg.auth_token
         if "kbapi_url" not in kwargs:
             kwargs["kbapi_url"] = cfg.kbapi_url
+        if "group" not in kwargs:
+            kwargs["group"] = cfg.group
+        if "project" not in kwargs:
+            kwargs["project"] = cfg.project
         super().__init__(*args, **kwargs)
 
 
