@@ -72,7 +72,12 @@ class Config:
         )
         self.tuxsuite_env = getenv("ENV", "default")
 
-        (self.auth_token, self.kbapi_url) = self._get_config_from_env()
+        (
+            self.auth_token,
+            self.kbapi_url,
+            self.group,
+            self.project,
+        ) = self._get_config_from_env()
 
         config_path = getenv("CONFIG", config_path)
 
@@ -80,9 +85,12 @@ class Config:
             config_path = get_config_file("config.ini")
 
         if not self.auth_token:
-            (self.auth_token, self.kbapi_url) = self._get_config_from_config(
-                config_path
-            )
+            (
+                self.auth_token,
+                self.kbapi_url,
+                self.group,
+                self.project,
+            ) = self._get_config_from_config(config_path)
 
         if not self.auth_token:
             raise tuxsuite.exceptions.TokenNotFound(
@@ -117,16 +125,22 @@ class Config:
             config[self.tuxsuite_env].get("api_url", self.default_api_url).rstrip("/")
         )
         auth_token = config[self.tuxsuite_env].get("token", None)
-        return (auth_token, kbapi_url)
+        group = config[self.tuxsuite_env].get("group", None)
+        project = config[self.tuxsuite_env].get("project", None)
+        return (auth_token, kbapi_url, group, project)
 
     def _get_config_from_env(self):
         # Check environment for TUXSUITE_TOKEN
         auth_token = None
         kbapi_url = None
+        group = None
+        project = None
         if getenv("TOKEN"):
             auth_token = getenv("TOKEN")
             kbapi_url = getenv("URL", self.default_api_url).rstrip("/")
-        return (auth_token, kbapi_url)
+            group = getenv("GROUP")
+            project = getenv("PROJECT")
+        return (auth_token, kbapi_url, group, project)
 
     def get_auth_token(self):
         return self.auth_token
@@ -137,15 +151,6 @@ class Config:
     def get_tuxsuite_env(self):
         return self.tuxsuite_env
 
-    def check_auth_token(self):
-        headers = {"Content-type": "application/json", "Authorization": self.auth_token}
-        url = self.kbapi_url + "/verify"
-        r = requests.get(url, headers=headers)
-        if r.status_code == 200:
-            return
-        else:
-            r.raise_for_status()  # Some unexpected status that's not caught
-
 
 InvalidConfiguration = tuxsuite.exceptions.InvalidConfiguration
 
